Stan Math Library: stan/math/prim/scal/prob/student_t_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

student_t_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_STUDENT_T_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_STUDENT_T_RNG_HPP
3
4 #include <boost/random/student_t_distribution.hpp>
5 #include <boost/random/variate_generator.hpp>
6 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
7 #include <stan/math/prim/scal/err/check_finite.hpp>
8 #include <stan/math/prim/scal/err/check_not_nan.hpp>
9 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
10 #include <stan/math/prim/scal/fun/constants.hpp>
11 #include <stan/math/prim/scal/fun/square.hpp>
12 #include <stan/math/prim/scal/fun/value_of.hpp>
13 #include <stan/math/prim/scal/fun/lbeta.hpp>
14 #include <stan/math/prim/scal/fun/lgamma.hpp>
15 #include <stan/math/prim/scal/fun/digamma.hpp>
16 #include <stan/math/prim/scal/meta/length.hpp>
17 #include <stan/math/prim/scal/fun/grad_reg_inc_beta.hpp>
18 #include <stan/math/prim/scal/fun/inc_beta.hpp>
19 #include <stan/math/prim/scal/meta/include_summand.hpp>
20 #include <stan/math/prim/scal/meta/VectorBuilder.hpp>
21
22 namespace stan {
23
24 namespace math {
25
26 template <class RNG>
27 inline double
28 student_t_rng(const double nu,
29 const double mu,
30 const double sigma,
31 RNG& rng) {
32 using boost::variate_generator;
33 using boost::random::student_t_distribution;
34
35 static const char* function("stan::math::student_t_rng");
36
37 using stan::math::check_positive_finite;
38 using stan::math::check_finite;
39
40 check_positive_finite(function, "Degrees of freedom parameter", nu);
41 check_finite(function, "Location parameter", mu);
42 check_positive_finite(function, "Scale parameter", sigma);
43
44 variate_generator<RNG&, student_t_distribution<> >
45 rng_unit_student_t(rng, student_t_distribution<>(nu));
46 return mu + sigma * rng_unit_student_t();
47 }
48 }
49 }
50 #endif
check_not_nan.hpp
lgamma.hpp
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
digamma.hpp
square.hpp
include_summand.hpp
stan::math::student_t_rng
double student_t_rng(const double nu, const double mu, const double sigma, RNG &rng)
Definition: student_t_rng.hpp:28
VectorBuilder.hpp
length.hpp
grad_reg_inc_beta.hpp
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
lbeta.hpp
inc_beta.hpp
value_of.hpp
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.